@@ -1,6 +1,6 @@
 package PDF::API2;
 
-our $VERSION = '2.022'; # VERSION
+our $VERSION = '2.024'; # VERSION
 
 use Carp;
 use Encode qw(:all);
@@ -135,8 +135,8 @@ B<Example:>
 
 sub open {
     my ($class, $file, %options) = @_;
-    die "File '$file' does not exist." unless -f $file;
-    die "File '$file' is not readable." unless -r $file;
+    croak "File '$file' does not exist" unless -f $file;
+    croak "File '$file' is not readable" unless -r $file;
 
     my $content;
     my $scalar_fh = FileHandle->new();
@@ -303,7 +303,8 @@ B<Initial Page Options>:
 
 =item -firstpage => [ $page, %options ]
 
-Specifying the page to be displayed, plus one of the following options:
+Specifying the page (either a page number or a page object) to be
+displayed, plus one of the following options:
 
 =over
 
@@ -462,31 +463,35 @@ sub preferences {
         my ($page, %args) = @{$options{-firstpage}};
         $args{'-fit'} = 1 unless scalar keys %args;
 
+        # $page can be either a page number (which needs to be wrapped
+        # in PDFNum) or a page object (which doesn't).
+        $page = PDFNum($page) unless ref($page);
+
         if (defined $args{'-fit'}) {
-            $self->{'catalog'}->{'OpenAction'} = PDFArray(PDFNum($page), PDFName('Fit'));
+            $self->{'catalog'}->{'OpenAction'} = PDFArray($page, PDFName('Fit'));
         }
         elsif (defined $args{'-fith'}) {
-            $self->{'catalog'}->{'OpenAction'} = PDFArray(PDFNum($page), PDFName('FitH'), PDFNum($args{'-fith'}));
+            $self->{'catalog'}->{'OpenAction'} = PDFArray($page, PDFName('FitH'), PDFNum($args{'-fith'}));
         }
         elsif (defined $args{'-fitb'}) {
-            $self->{'catalog'}->{'OpenAction'} = PDFArray(PDFNum($page), PDFName('FitB'));
+            $self->{'catalog'}->{'OpenAction'} = PDFArray($page, PDFName('FitB'));
         }
         elsif (defined $args{'-fitbh'}) {
-            $self->{'catalog'}->{'OpenAction'} = PDFArray(PDFNum($page), PDFName('FitBH'), PDFNum($args{'-fitbh'}));
+            $self->{'catalog'}->{'OpenAction'} = PDFArray($page, PDFName('FitBH'), PDFNum($args{'-fitbh'}));
         }
         elsif (defined $args{'-fitv'}) {
-            $self->{'catalog'}->{'OpenAction'} = PDFArray(PDFNum($page), PDFName('FitV'), PDFNum($args{'-fitv'}));
+            $self->{'catalog'}->{'OpenAction'} = PDFArray($page, PDFName('FitV'), PDFNum($args{'-fitv'}));
         }
         elsif (defined $args{'-fitbv'}) {
-            $self->{'catalog'}->{'OpenAction'} = PDFArray(PDFNum($page), PDFName('FitBV'), PDFNum($args{'-fitbv'}));
+            $self->{'catalog'}->{'OpenAction'} = PDFArray($page, PDFName('FitBV'), PDFNum($args{'-fitbv'}));
         }
         elsif (defined $args{'-fitr'}) {
             croak 'insufficient parameters to -fitr => []' unless scalar @{$args{'-fitr'}} == 4;
-            $self->{'catalog'}->{'OpenAction'} = PDFArray(PDFNum($page), PDFName('FitR'), map { PDFNum($_) } @{$args{'-fitr'}});
+            $self->{'catalog'}->{'OpenAction'} = PDFArray($page, PDFName('FitR'), map { PDFNum($_) } @{$args{'-fitr'}});
         }
         elsif (defined $args{'-xyz'}) {
             croak 'insufficient parameters to -xyz => []' unless scalar @{$args{'-xyz'}} == 3;
-            $self->{'catalog'}->{'OpenAction'} = PDFArray(PDFNum($page), PDFName('XYZ'), map { PDFNum($_) } @{$args{'-xyz'}});
+            $self->{'catalog'}->{'OpenAction'} = PDFArray($page, PDFName('XYZ'), map { PDFNum($_) } @{$args{'-xyz'}});
         }
     }
     $self->{'pdf'}->out_obj($self->{'catalog'});
@@ -1283,6 +1288,7 @@ sub importPageIntoForm {
     $self->{apiimportcache}||={};
     $self->{apiimportcache}->{$s_pdf}||={};
 
+    # Should never get past MediaBox, since it is a required object.
     foreach my $k (qw( MediaBox ArtBox TrimBox BleedBox CropBox )) {
         #next unless(defined $s_page->{$k});
         #my $box = walk_obj($self->{apiimportcache}->{$s_pdf},$s_pdf->{pdf},$self->{pdf},$s_page->{$k});
@@ -1402,7 +1408,18 @@ sub import_page {
     # all that nasty resources from polluting
     # our very own resource naming space.
     my $xo = $self->importPageIntoForm($s_pdf,$s_page);
-    $t_page->mediabox( map { $_->val } $xo->{BBox}->elementsof) if(defined $xo->{BBox});
+
+    # copy all page dimensions
+    foreach my $k (qw( MediaBox ArtBox TrimBox BleedBox CropBox )) {
+        my $prop = $s_page->find_prop($k);
+        next unless defined $prop;
+
+        my $box = walk_obj({}, $s_pdf->{pdf}, $self->{pdf}, $prop);
+        my $method = lc($k);
+
+        $t_page->$method(map { $_->val } $box->elementsof);
+    }
+
     $t_page->gfx->formimage($xo,0,0,1);
 
     # copy annotations and/or form elements as well
