@@ -1,6 +1,6 @@
 package PDF::API2::Resource::XObject::Form::BarCode::codabar;
 
-our $VERSION = '2.023'; # VERSION
+our $VERSION = '2.024'; # VERSION
 
 use base 'PDF::API2::Resource::XObject::Form::BarCode';
 
@@ -13,7 +13,7 @@ sub new {
 
     my @bars = $self->encode($options{'-code'});
 
-    $self->drawbar([@bars]);
+    $self->drawbar([@bars], $options{'caption'});
 
     return $self;
 }
